==> patch_xss_8.14.1.3_20241106.tgz: login/login.php <==
<?
require("$_SERVER[DOCUMENT_ROOT]/lib/php/base.php");

$_user = value($_GET, 'user', NULL);    // User name for authentication without web interface.
$_pass = value($_GET, 'pass', NULL);    // User password for authentication without web interface.

$_msg  = urldecode(reqval('msg',''));     // To display an error message.

$url   = NULL;                          // URL of new window to open at load.

//  Process direct API login call
if ($_user != NULL && $_pass != NULL)
{
    $_auth   = value($_GET, 'auth', NULL);
    $_camera = value($_GET, 'camera', NULL);
    $_desk   = value($_GET, 'desk', NULL);
    $_group  = value($_GET, 'group', NULL);
    $_map    = value($_GET, 'map', NULL);

    $url = "/login/check.php?login=$_user&passwd=$_pass";

    $arg = '';
    if ($_camera != NULL)
        $arg = "&camera=$_camera";
    else if ($_desk != NULL)
        $arg = "&desk=$_desk";
    else if ($_group != NULL)
        $arg = "&group=$_group";
    else if ($_map != NULL)
        $arg = "&map=$_map";

    // If no arguments other than user/pass, we are just identifying
    if (empty($arg))
    {
        $url .= '&auth=';
        if ($_auth != NULL) // Pass on auth if declared
            $url .= rawurlencode($_auth);
        Trace("\tredirecting to \"$url\"");
        header("Location: $url");
        exit();
    }

    // Otherwise we want a main menu with a desk/camera/group/map
    $url .= $arg;
}

DocType();
?>
<html>
    <head>
        <?
        Entetes(HDR_CHARSET|HDR_STYLES,gettext("TxtAuthCamTrace"));
        include("$_SERVER[DOCUMENT_ROOT]/lib/js/resize.php");
        ?>
        <script type="text/javascript">
        var ww  = 420;
        var wh  = 240;
        var msg = "<?=jschars($_msg)?>";
        var url = "<?=$url?>";

        if (url.length > 0) // >0 only for check and main menu if ok.
            open(url + '&opnr=' + name, "<?=$HostName?>_menu", 'width=' + ww + ',height=' + wh);

	// When /login/login.php directly called or when there is a close argument in the url.
	if (name == '' || <?=isset($_GET['close']) ? 'true' : 'false'?>)
	{
	    window.open('', '_self', '');
	    window.close();
	}

        window.onload = function () {
	    if (top.name != '')
	    {
		var sz = resize_to(ww,wh);
		top.moveTo((screen.width - sz.w) / 2, (screen.height - sz.h) / 2);
	    }

            if (msg.length > 0)
                alert(msg);

            window.focus();
            document.auth.login.focus();
        }
			function langChange() {
				document.forms['auth'].action = '/login/login.php';
				document.forms['auth'].submit();
			}
        </script>
    </head>
<body>
  <form name='auth' method='post' action='/login/check.php'>
    <div class='centered' style='width:100%;'>
      <img src='<?=logo('l')?>' style='width:407px;height:82px;border:0px none;padding-top:4px;' alt='Logo'>
      <script type="text/javascript">
	if (!navigator.cookieEnabled)
	  document.write("<div class='centered onerror' style='font-size:12px;'><?=br_text('MsgCookiesDisabled')?></div>");
      </script>
      <div style='width:300px;margin-left:auto;margin-right:auto;margin-top:12px;'>
      <table style='border:0px none;margin-top:12px;'>
	<tr>
	  <td class="searchtag" style='text-align:right;'><?=gettext("TxtUserLogin")?></td>
	  <td style='text-align:left;'>
	    <input type='text' name='login' style='width:110px;' value='<?=htmlspecialchars(reqval('login'))?>'>
	  </td>
	</tr>
	<tr>
	  <td class="searchtag" style='text-align:right;'><?=gettext("TxtUserPasswd")?></td>
	  <td style='text-align:left;'>
	    <input type='password' name='passwd' style='width:110px;' value='<?=htmlspecialchars(reqval('passwd'))?>'>
	  </td>
	</tr>
	<tr>
	  <td class="searchtag" style='text-align:right;'><?=gettext("InpLoginLanguage")?></td>
	  <td style='text-align:left;'>
	    <select id='lang' class='txt_elt' name='lang' style='width:110px;' onChange='langChange();'>
<?		exec("$_CT[BIN]/camlangs", $lines);
		for ($i = 0; $i < count($lines); $i++)
		{
		    list($code,$name) = explode("\t", $lines[$i]);
		    $sel = ($code == $_SESSION['UserLang']) ? " selected" : "";?>
	      <option value='<?=$code?>'<?=$sel?>><?=$name?></option>
<?		}?>
	    </select>
	  </td>
	</tr>
      </table>
      <div style='margin-top:12px;'>
	<input type='submit' class='btn' name='enter' value='<?=gettext("BtnEnter")?>'>
	<input type='reset'  class='btn' name='cancel' value='<?=gettext("BtnCancel")?>' onClick='document.auth.login.focus()'>
	<input type='button' class='btn' name='close' value='<?=gettext("BtnClose")?>' onClick='self.close()'>
      </div>
      </div>
    </div>
  </form>
</body>
</html>

==> patch_xss_8.15.2.2_20241106.tgz: login/login.php <==
<?php
require("$_SERVER[DOCUMENT_ROOT]/lib/php/base.php");

$_user = value($_GET, 'user', null);    // User name for authentication without web interface.
$_pass = value($_GET, 'pass', null);    // User password for authentication without web interface.

$_msg  = urldecode(reqval('msg', ''));     // To display an error message.

$url   = null;                          // URL of new window to open at load.

//  Process direct API login call
if ($_user != null && $_pass != null) {
    $_auth   = value($_GET, 'auth', null);
    $_camera = value($_GET, 'camera', null);
    $_desk   = value($_GET, 'desk', null);
    $_group  = value($_GET, 'group', null);
    $_map    = value($_GET, 'map', null);

    $url = "/login/check.php?login=$_user&passwd=$_pass";

    $arg = '';
    if ($_camera != null) {
        $arg = "&camera=$_camera";
    } elseif ($_desk != null) {
        $arg = "&desk=$_desk";
    } elseif ($_group != null) {
        $arg = "&group=$_group";
    } elseif ($_map != null) {
        $arg = "&map=$_map";
    }

    // If no arguments other than user/pass, we are just identifying
    if (empty($arg)) {
        $url .= '&auth=';
        if ($_auth != null) { // Pass on auth if declared
            $url .= rawurlencode($_auth);
        }
        Trace("\tredirecting to \"$url\"");
        header("Location: $url");
        exit();
    }

    // Otherwise we want a main menu with a desk/camera/group/map
    $url .= $arg;
}

DocType();
?>
<html>
    <head>
        <?php
        Entetes(HDR_CHARSET|HDR_STYLES, gettext("TxtAuthCamTrace"));
        include("$_SERVER[DOCUMENT_ROOT]/lib/js/resize.php");
        ?>
        <script type="text/javascript">
        var ww  = 420;
        var wh  = 240;
        var msg = "<?=jschars($_msg)?>";
        var url = "<?=$url?>";

        if (url.length > 0) // >0 only for check and main menu if ok.
            open(url + '&opnr=' + name, "<?=$HostName?>_menu", 'width=' + ww + ',height=' + wh);

	// When /login/login.php directly called or when there is a close argument in the url.
	if (name == '' || <?=isset($_GET['close']) ? 'true' : 'false'?>)
	{
	    window.open('', '_self', '');
	    window.close();
	}

        window.onload = function () {
	    if (top.name != '')
	    {
		var sz = resize_to(ww,wh);
		top.moveTo((screen.width - sz.w) / 2, (screen.height - sz.h) / 2);
	    }

            if (msg.length > 0)
                alert(msg);

            window.focus();
            document.auth.login.focus();
        }
			function langChange() {
				document.forms['auth'].action = '/login/login.php';
				document.forms['auth'].submit();
			}
        </script>
    </head>
<body>
  <form name='auth' method='post' action='/login/check.php'>
    <div class='centered' style='width:100%;'>
      <img src='<?=logo('l')?>' style='width:407px;height:82px;border:0px none;padding-top:4px;' alt='Logo'>
      <script type="text/javascript">
	if (!navigator.cookieEnabled)
	  document.write("<div class='centered onerror' style='font-size:12px;'><?=br_text('MsgCookiesDisabled')?></div>");
      </script>
      <div style='width:300px;margin-left:auto;margin-right:auto;margin-top:12px;'>
      <table style='border:0px none;margin-top:12px;'>
	<tr>
	  <td class="searchtag" style='text-align:right;'><?=gettext("TxtUserLogin")?></td>
	  <td style='text-align:left;'>
	    <input type='text' name='login' style='width:110px;' value='<?=htmlspecialchars(reqval('login'))?>'>
	  </td>
	</tr>
	<tr>
	  <td class="searchtag" style='text-align:right;'><?=gettext("TxtUserPasswd")?></td>
	  <td style='text-align:left;'>
	    <input type='password' name='passwd' style='width:110px;' value='<?=htmlspecialchars(reqval('passwd'))?>'>
	  </td>
	</tr>
	<tr>
	  <td class="searchtag" style='text-align:right;'><?=gettext("InpLoginLanguage")?></td>
	  <td style='text-align:left;'>
	    <select id='lang' class='txt_elt' name='lang' style='width:110px;' onChange='langChange();'>
<?php		exec("$_CT[BIN]/camlangs", $lines);
        for ($i = 0; $i < count($lines); $i++) {
            list($code,$name) = explode("\t", $lines[$i]);
            $sel = ($code == $_SESSION['UserLang']) ? " selected" : ""; ?>
	      <option value='<?=$code?>'<?=$sel?>><?=$name?></option>
<?php
        }?>
	    </select>
	  </td>
	</tr>
      </table>
      <div style='margin-top:12px;'>
	<input type='submit' class='btn' name='enter' value='<?=gettext("BtnEnter")?>'>
	<input type='reset'  class='btn' name='cancel' value='<?=gettext("BtnCancel")?>' onClick='document.auth.login.focus()'>
	<input type='button' class='btn' name='close' value='<?=gettext("BtnClose")?>' onClick='self.close()'>
      </div>
      </div>
    </div>
  </form>
</body>
</html>
